@@ -2,11 +2,11 @@
 #include <rapidjson/document.h>
 #include <rapidjson/istreamwrapper.h>
 
-#include "geojsonsf.h"
-#include "geojson_to_sf.h"
-#include "geojson_sfc.h"
-#include "geojson_sfg.h"
-#include "geojson_properties.h"
+#include "geojsonsf/geojsonsf.h"
+#include "geojsonsf/geojson_to_sf.h"
+#include "geojsonsf/geojson_sfc.h"
+#include "geojsonsf/geojson_sfg.h"
+#include "geojsonsf/geojson_properties.h"
 #include <fstream>
 
 using namespace Rcpp;
